Learn R Programming

flightplanning (version 0.8.4)

litchi.plan: Function to generate Litchi csv flight plan

Description

Function to generate Litchi csv flight plan

Usage

litchi.plan(
  roi,
  output,
  flight.params,
  gimbal.pitch.angle = -90,
  flight.lines.angle = -1,
  max.waypoints.distance = 2000,
  max.flight.time = 15,
  starting.point = 1
)

Arguments

roi

range of interest loaded as an OGR layer, must be in a metric units projection for working properly

output

output path for the csv file

flight.params

Flight Parameters. parameters calculated from flight.parameters()

gimbal.pitch.angle

gimbal angle for taking photos, default -90 (overriden at flight time)

flight.lines.angle

angle for the flight lines, default -1 (auto set based on larger direction)

max.waypoints.distance

maximum distance between waypoints in meters, default 2000 (some issues have been reported with distances > 2 Km)

max.flight.time

maximum flight time. If mission is greater than the estimated time, it will be splitted into smaller missions.

starting.point

numeric (1, 2, 3 or 4). Change position from which to start the flight, default 1

Value

A data frame with the waypoints calculated for the flight plan

Examples

Run this code
# NOT RUN {
library(flightplanning)
library(rgdal)

exampleBoundary = readOGR(
                          system.file("extdata",
                                      "exampleBoundary.shp",
                                      package="flightplanning"
                                     ),
                          "exampleBoundary")
outPath = tempfile(fileext=".csv")

flight.params = flight.parameters(
  gsd = 4,
  side.overlap = 0.8,
  front.overlap = 0.8,
  flight.speed.kmh = 54
)

litchi.plan(exampleBoundary,
            outPath,
            flight.params,
            flight.lines.angle = -1,
            max.waypoints.distance = 2000,
            max.flight.time = 15)


# }

Run the code above in your browser using DataLab